Class: Danger::CircleAPI

Inherits:
Object
  • Object
show all
Defined in:
lib/danger/ci_source/circle_api.rb

Instance Method Summary collapse

Instance Method Details

#clientObject



32
33
34
# File 'lib/danger/ci_source/circle_api.rb', line 32

def client
  @client ||= Faraday.new(url: "https://circleci.com/api/v1")
end

#fetch_build(repo_slug, build_number, token) ⇒ Object

Make the API call, and parse the JSON



46
47
48
49
50
51
# File 'lib/danger/ci_source/circle_api.rb', line 46

def fetch_build(repo_slug, build_number, token)
  url = "project/#{repo_slug}/#{build_number}"
  params = { "circle-token" => token }
  response = client.get url, params, accept: "application/json"
  JSON.parse(response.body, symbolize_names: true)
end

#fetch_pull_request_url(repo_slug, build_number, token) ⇒ Object

Ask the API if the commit is inside a PR



37
38
39
40
41
42
43
# File 'lib/danger/ci_source/circle_api.rb', line 37

def fetch_pull_request_url(repo_slug, build_number, token)
  build_json = fetch_build(repo_slug, build_number, token)
  pull_requests = build_json[:pull_requests]
  return nil unless pull_requests&.first

  pull_requests.first[:url]
end

#pull_request?(env) ⇒ Boolean

Determine if there’s a PR attached to this commit, and return a bool

Returns:

  • (Boolean)


9
10
11
12
# File 'lib/danger/ci_source/circle_api.rb', line 9

def pull_request?(env)
  url = pull_request_url(env)
  return !url.nil?
end

#pull_request_url(env) ⇒ Object

Determine if there’s a PR attached to this commit, and return the url if so



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
# File 'lib/danger/ci_source/circle_api.rb', line 16

def pull_request_url(env)
  url = env["CI_PULL_REQUEST"]

  if url.nil? && !env["CIRCLE_PROJECT_USERNAME"].nil? && !env["CIRCLE_PROJECT_REPONAME"].nil?
    repo_slug = "#{env['CIRCLE_PROJECT_USERNAME']}/#{env['CIRCLE_PROJECT_REPONAME']}"
    if !env["CIRCLE_PR_NUMBER"].nil?
      host = env["DANGER_GITHUB_HOST"] || "github.com"
      url = "https://#{host}/#{repo_slug}/pull/#{env['CIRCLE_PR_NUMBER']}"
    else
      token = env["DANGER_CIRCLE_CI_API_TOKEN"]
      url = fetch_pull_request_url(repo_slug, env["CIRCLE_BUILD_NUM"], token)
    end
  end
  url
end