Class: Danger::RequestSources::BitbucketCloud

Inherits:
RequestSource show all
Includes:
Helpers::CommentsHelper
Defined in:
lib/danger/request_sources/bitbucket_cloud.rb

Constant Summary

Constants inherited from RequestSource

RequestSource::DANGER_REPO_NAME

Instance Attribute Summary collapse

Attributes inherited from RequestSource

#ci_source, #ignored_violations

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Helpers::CommentsHelper

#apply_template, #generate_comment, #generate_description, #generate_inline_comment_body, #generate_inline_markdown_body, #generate_message_group_comment, #markdown_link_to_message, #markdown_parser, #messages_are_equivalent, #process_markdown, #random_compliment, #table

Methods included from Helpers::CommentsParsingHelper

#parse_comment, #parse_message_from_row, #parse_tables_from_comment, #table_kind_from_title, #violations_from_table

Methods inherited from RequestSource

available_request_sources, available_source_names_and_envs, #file_url, inherited, #inspect, source_name, #update_build_status

Constructor Details

#initialize(ci_source, environment) ⇒ BitbucketCloud

Returns a new instance of BitbucketCloud.



32
33
34
35
36
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 32

def initialize(ci_source, environment)
  self.ci_source = ci_source

  @api = BitbucketCloudAPI.new(ci_source.repo_slug, ci_source.pull_request_id, nil, environment)
end

Instance Attribute Details

#pr_jsonObject

Returns the value of attribute pr_json.



11
12
13
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 11

def pr_json
  @pr_json
end

Class Method Details

.env_varsObject



13
14
15
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 13

def self.env_vars
  ["DANGER_BITBUCKETCLOUD_UUID"]
end

.optional_env_varsObject

While it says “optional”, one of these is required to run Danger on Bitbucket Cloud.

  • Both ‘DANGER_BITBUCKETCLOUD_OAUTH_KEY` and `DANGER_BITBUCKETCLOUD_OAUTH_SECRET`

  • Both ‘DANGER_BITBUCKETCLOUD_USERNAME` and `DANGER_BITBUCKETCLOUD_PASSWORD`

  • ‘DANGER_BITBUCKETCLOUD_REPO_ACCESSTOKEN`



22
23
24
25
26
27
28
29
30
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 22

def self.optional_env_vars
  [
    "DANGER_BITBUCKETCLOUD_OAUTH_KEY",
    "DANGER_BITBUCKETCLOUD_OAUTH_SECRET",
    "DANGER_BITBUCKETCLOUD_REPO_ACCESSTOKEN",
    "DANGER_BITBUCKETCLOUD_USERNAME",
    "DANGER_BITBUCKETCLOUD_PASSWORD"
  ]
end

Instance Method Details

#delete_old_comments(danger_id: "danger") ⇒ Object



169
170
171
172
173
174
175
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 169

def delete_old_comments(danger_id: "danger")
  @api.fetch_comments.each do |c|
    next if c[:user][:uuid] != @api.my_uuid

    @api.delete_comment(c[:id]) if c[:content][:raw] =~ /generated_by_#{danger_id}/
  end
end

#fetch_detailsObject



55
56
57
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 55

def fetch_details
  self.pr_json = @api.fetch_pr_json
end

#hostObject



51
52
53
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 51

def host
  @host ||= @api.host
end

#organisationObject



75
76
77
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 75

def organisation
  nil
end

#scmObject



47
48
49
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 47

def scm
  @scm ||= GitRepo.new
end

#setup_danger_branchesObject



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 59

def setup_danger_branches
  base_branch = self.pr_json[:destination][:branch][:name]
  base_commit = self.pr_json[:destination][:commit][:hash]
  head_branch = self.pr_json[:source][:branch][:name]
  head_commit = self.pr_json[:source][:commit][:hash]

  # Next, we want to ensure that we have a version of the current branch at a known location
  scm.ensure_commitish_exists_on_branch! base_branch, base_commit
  self.scm.exec "branch #{EnvironmentManager.danger_base_branch} #{base_commit}"

  # OK, so we want to ensure that we have a known head branch, this will always represent
  # the head of the PR ( e.g. the most recent commit that will be merged. )
  scm.ensure_commitish_exists_on_branch! head_branch, head_commit
  self.scm.exec "branch #{EnvironmentManager.danger_head_branch} #{head_commit}"
end

#update_inline_comments_for_kind!(kind, messages, danger_id: "danger") ⇒ Object



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 145

def update_inline_comments_for_kind!(kind, messages, danger_id: "danger")
  emoji = { warnings: "warning", errors: "no_entry_sign", messages: "book" }[kind]

  messages.reject do |message|
    next false unless message.file && message.line

    body = ""

    if kind == :markdown
      body = generate_inline_markdown_body(message,
                                           danger_id: danger_id,
                                           template: "bitbucket_server")
    else
      body = generate_inline_comment_body(emoji, message,
                                          danger_id: danger_id,
                                          template: "bitbucket_server")
    end

    @api.post_comment(body, file: message.file, line: message.line)

    true
  end
end

#update_pr_by_line!(message_groups:, danger_id: "danger", new_comment: false, remove_previous_comments: false) ⇒ Object



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 102

def (message_groups:,
                       danger_id: "danger",
                       new_comment: false,
                       remove_previous_comments: false)
  if !new_comment || remove_previous_comments
    delete_old_comments(danger_id: danger_id)
  end

  summary_body = generate_description(warnings: message_groups.fake_warnings_array,
                                      errors: message_groups.fake_errors_array,
                                      template: "bitbucket_server")
  summary_body += "\n\n"

  # this isn't the most elegant thing in the world, but we need the group
  # with file: nil, line: nil so we can combine its info in with the
  # summary_body
  summary_group = message_groups.first
  if summary_group && summary_group.file.nil? && summary_group.line.nil?
    # remove summary_group from message_groups so it doesn't get a
    # duplicate comment posted in the message_groups loop below
    message_groups.shift
  else
    summary_group = MessageGroup.new(file: nil, line: nil)
  end

  summary_body += generate_message_group_comment(
    message_group: summary_group,
    danger_id: danger_id,
    template: "bitbucket_server_message_group"
  )

  @api.post_comment(summary_body)

  message_groups.each do |message_group|
    body = generate_message_group_comment(message_group: message_group,
                                          danger_id: danger_id,
                                          template: "bitbucket_server_message_group")
    @api.post_comment(body,
                      file: message_group.file,
                      line: message_group.line)
  end
end

#update_pull_request!(warnings: [], errors: [], messages: [], markdowns: [], danger_id: "danger", new_comment: false, remove_previous_comments: false) ⇒ Object



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 79

def update_pull_request!(warnings: [], errors: [], messages: [], markdowns: [], danger_id: "danger", new_comment: false, remove_previous_comments: false)
  delete_old_comments(danger_id: danger_id) if !new_comment || remove_previous_comments

  warnings = update_inline_comments_for_kind!(:warnings, warnings, danger_id: danger_id)
  errors = update_inline_comments_for_kind!(:errors, errors, danger_id: danger_id)
  messages = update_inline_comments_for_kind!(:messages, messages, danger_id: danger_id)
  markdowns = update_inline_comments_for_kind!(:markdowns, markdowns, danger_id: danger_id)

  has_comments = warnings.count.positive? || errors.count.positive? || messages.count.positive? || markdowns.count.positive?
  if has_comments
    comment = generate_description(warnings: warnings, errors: errors, template: "bitbucket_server")
    comment += "\n\n"
    comment += generate_comment(warnings: warnings,
                                errors: errors,
                                messages: messages,
                                markdowns: markdowns,
                                previous_violations: {},
                                danger_id: danger_id,
                                template: "bitbucket_server")
    @api.post_comment(comment)
  end
end

#validates_as_api_source?Boolean

Returns:

  • (Boolean)


43
44
45
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 43

def validates_as_api_source?
  @api.credentials_given?
end

#validates_as_ci?Boolean

Returns:

  • (Boolean)


38
39
40
41
# File 'lib/danger/request_sources/bitbucket_cloud.rb', line 38

def validates_as_ci?
  # TODO: ???
  true
end