Class: Danger::RequestSources::BitbucketServer

Inherits:
RequestSource show all
Includes:
Helpers::CommentsHelper
Defined in:
lib/danger/request_sources/bitbucket_server.rb

Constant Summary

Constants inherited from RequestSource

RequestSource::DANGER_REPO_NAME

Instance Attribute Summary collapse

Attributes inherited from RequestSource

#ci_source, #ignored_violations

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Helpers::CommentsHelper

#apply_template, #generate_comment, #generate_description, #generate_inline_comment_body, #generate_inline_markdown_body, #generate_message_group_comment, #markdown_link_to_message, #markdown_parser, #messages_are_equivalent, #process_markdown, #random_compliment, #table

Methods included from Helpers::CommentsParsingHelper

#parse_comment, #parse_message_from_row, #parse_tables_from_comment, #table_kind_from_title, #violations_from_table

Methods inherited from RequestSource

available_request_sources, available_source_names_and_envs, #file_url, inherited, #inspect, source_name, #update_build_status

Constructor Details

#initialize(ci_source, environment) ⇒ BitbucketServer

Returns a new instance of BitbucketServer.



33
34
35
36
37
38
39
40
# File 'lib/danger/request_sources/bitbucket_server.rb', line 33

def initialize(ci_source, environment)
  self.ci_source = ci_source
  self.dismiss_out_of_range_messages = environment["DANGER_BITBUCKETSERVER_DISMISS_OUT_OF_RANGE_MESSAGES"] == "true"

  project, slug = ci_source.repo_slug.split("/")
  @api = BitbucketServerAPI.new(project, slug, ci_source.pull_request_id, environment)
  @code_insights = CodeInsightsAPI.new(project, slug, environment)
end

Instance Attribute Details

#dismiss_out_of_range_messagesObject

Returns the value of attribute dismiss_out_of_range_messages.



12
13
14
# File 'lib/danger/request_sources/bitbucket_server.rb', line 12

def dismiss_out_of_range_messages
  @dismiss_out_of_range_messages
end

#pr_jsonObject

Returns the value of attribute pr_json.



12
13
14
# File 'lib/danger/request_sources/bitbucket_server.rb', line 12

def pr_json
  @pr_json
end

Class Method Details

.env_varsObject



14
15
16
17
18
19
20
# File 'lib/danger/request_sources/bitbucket_server.rb', line 14

def self.env_vars
  [
    "DANGER_BITBUCKETSERVER_USERNAME",
    "DANGER_BITBUCKETSERVER_PASSWORD",
    "DANGER_BITBUCKETSERVER_HOST"
  ]
end

.optional_env_varsObject



22
23
24
25
26
27
28
29
30
31
# File 'lib/danger/request_sources/bitbucket_server.rb', line 22

def self.optional_env_vars
  [
    "DANGER_BITBUCKETSERVER_CODE_INSIGHTS_REPORT_KEY",
    "DANGER_BITBUCKETSERVER_CODE_INSIGHTS_REPORT_TITLE",
    "DANGER_BITBUCKETSERVER_CODE_INSIGHTS_REPORT_DESCRIPTION",
    "DANGER_BITBUCKETSERVER_CODE_INSIGHTS_REPORT_LOGO_URL",
    "DANGER_BITBUCKETSERVER_VERIFY_SSL",
    "DANGER_BITBUCKETSERVER_DISMISS_OUT_OF_RANGE_MESSAGES"
  ]
end

Instance Method Details

#added_lines(file) ⇒ Object



200
201
202
203
204
205
206
207
208
209
# File 'lib/danger/request_sources/bitbucket_server.rb', line 200

def added_lines(file)
  @added_lines ||= {}
  @added_lines[file] ||= file_diff(file)[:hunks].map do |hunk|
    hunk[:segments].select { |segment| segment[:type] == "ADDED" }.map do |segment|
      segment[:lines].map do |line|
        line[:destination]
      end
    end
  end.flatten
end

#delete_old_comments(danger_id: "danger") ⇒ Object



136
137
138
139
140
# File 'lib/danger/request_sources/bitbucket_server.rb', line 136

def delete_old_comments(danger_id: "danger")
  @api.fetch_last_comments.each do |c|
    @api.delete_comment(c[:id], c[:version]) if c[:text] =~ /generated_by_#{danger_id}/
  end
end

#fetch_detailsObject



59
60
61
# File 'lib/danger/request_sources/bitbucket_server.rb', line 59

def fetch_details
  self.pr_json = @api.fetch_pr_json
end

#file_diff(file) ⇒ Object



196
197
198
# File 'lib/danger/request_sources/bitbucket_server.rb', line 196

def file_diff(file)
  self.pr_diff[:diffs].find { |diff| diff[:destination] && diff[:destination][:toString] == file } || { hunks: [] }
end

#find_position_in_diff?(file, line) ⇒ Boolean

Returns:

  • (Boolean)


189
190
191
192
193
194
# File 'lib/danger/request_sources/bitbucket_server.rb', line 189

def find_position_in_diff?(file, line)
  return nil if file.nil? || line.nil?
  return nil if file.empty?

  added_lines(file).include?(line)
end

#hostObject



55
56
57
# File 'lib/danger/request_sources/bitbucket_server.rb', line 55

def host
  @host ||= @api.host
end

#inline_violations_group(warnings: [], errors: [], messages: [], markdowns: []) ⇒ Object



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/danger/request_sources/bitbucket_server.rb', line 161

def inline_violations_group(warnings: [], errors: [], messages: [], markdowns: [])
  cmp = proc do |a, b|
    next -1 unless a.file && a.line
    next 1 unless b.file && b.line

    next a.line <=> b.line if a.file == b.file

    next a.file <=> b.file
  end

  # Sort to group inline comments by file
  {
    warnings: warnings.select(&:inline?).sort(&cmp),
    errors: errors.select(&:inline?).sort(&cmp),
    messages: messages.select(&:inline?).sort(&cmp),
    markdowns: markdowns.select(&:inline?).sort(&cmp)
  }
end

#main_violations_group(warnings: [], errors: [], messages: [], markdowns: []) ⇒ Object



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/danger/request_sources/bitbucket_server.rb', line 142

def main_violations_group(warnings: [], errors: [], messages: [], markdowns: [])
  if dismiss_out_of_range_messages
    {
      warnings: warnings.reject(&:inline?),
      errors: errors.reject(&:inline?),
      messages: messages.reject(&:inline?),
      markdowns: markdowns.reject(&:inline?)
    }
  else
    in_diff = proc { |a| find_position_in_diff?(a.file, a.line) }
    {
      warnings: warnings.reject(&in_diff),
      errors: errors.reject(&in_diff),
      messages: messages.reject(&in_diff),
      markdowns: markdowns.reject(&in_diff)
    }
  end
end

#organisationObject



87
88
89
# File 'lib/danger/request_sources/bitbucket_server.rb', line 87

def organisation
  nil
end

#pr_diffObject



63
64
65
# File 'lib/danger/request_sources/bitbucket_server.rb', line 63

def pr_diff
  @pr_diff ||= @api.fetch_pr_diff
end

#scmObject



51
52
53
# File 'lib/danger/request_sources/bitbucket_server.rb', line 51

def scm
  @scm ||= GitRepo.new
end

#setup_danger_branchesObject



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/danger/request_sources/bitbucket_server.rb', line 67

def setup_danger_branches
  base_branch = self.pr_json[:toRef][:id].sub("refs/heads/", "")
  base_commit = self.pr_json[:toRef][:latestCommit]
  # Support for older versions of Bitbucket Server
  base_commit = self.pr_json[:toRef][:latestChangeset] if self.pr_json[:fromRef].key? :latestChangeset
  head_branch = self.pr_json[:fromRef][:id].sub("refs/heads/", "")
  head_commit = self.pr_json[:fromRef][:latestCommit]
  # Support for older versions of Bitbucket Server
  head_commit = self.pr_json[:fromRef][:latestChangeset] if self.pr_json[:fromRef].key? :latestChangeset

  # Next, we want to ensure that we have a version of the current branch at a known location
  scm.ensure_commitish_exists_on_branch! base_branch, base_commit
  self.scm.exec "branch #{EnvironmentManager.danger_base_branch} #{base_commit}"

  # OK, so we want to ensure that we have a known head branch, this will always represent
  # the head of the PR ( e.g. the most recent commit that will be merged. )
  scm.ensure_commitish_exists_on_branch! head_branch, head_commit
  self.scm.exec "branch #{EnvironmentManager.danger_head_branch} #{head_commit}"
end

#update_pr_build_status(status, build_job_link, description) ⇒ Object



180
181
182
183
184
185
186
187
# File 'lib/danger/request_sources/bitbucket_server.rb', line 180

def update_pr_build_status(status, build_job_link, description)
  changeset = self.pr_json[:fromRef][:latestCommit]
  # Support for older versions of Bitbucket Server
  changeset = self.pr_json[:fromRef][:latestChangeset] if self.pr_json[:fromRef].key? :latestChangeset
  puts "Changeset: #{changeset}"
  puts self.pr_json.to_json
  @api.update_pr_build_status(status, changeset, build_job_link, description)
end

#update_pull_request!(warnings: [], errors: [], messages: [], markdowns: [], danger_id: "danger", new_comment: false, remove_previous_comments: false) ⇒ Object



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/danger/request_sources/bitbucket_server.rb', line 91

def update_pull_request!(warnings: [], errors: [], messages: [], markdowns: [], danger_id: "danger", new_comment: false, remove_previous_comments: false)
  delete_old_comments(danger_id: danger_id) if !new_comment || remove_previous_comments

  # If configured, send a Code Insights API to provide the PR with a quality report
  # which includes inline code violations found by Danger as Annotations.
  # If no inline violations occurred, an empty, successful (green) report will be sent.
  if @code_insights.ready?
    inline_violations = inline_violations_group(warnings: warnings, errors: errors, messages: messages)
    inline_warnings = inline_violations[:warnings] || []
    inline_errors = inline_violations[:errors] || []
    inline_messages = inline_violations[:messages] || []

    head_commit = self.pr_json[:fromRef][:latestCommit]
    @code_insights.send_report(head_commit,
                               inline_warnings,
                               inline_errors,
                               inline_messages)
  end

  # If we're sending inline comments separately via Code Insights,
  # the main body comment should contain only generic, non-file specific messages.
  if @code_insights.ready?
    main_violations = main_violations_group(warnings: warnings, errors: errors, messages: messages)
    warnings = main_violations[:warnings] || []
    errors = main_violations[:errors] || []
    messages = main_violations[:messages] || []
    markdowns = main_violations[:markdowns] || []
  end

  has_comments = warnings.count > 0 || errors.count > 0 || messages.count > 0 || markdowns.count > 0
  if has_comments
    comment = generate_description(warnings: warnings,
                                   errors: errors)
    comment += "\n\n"
    comment += generate_comment(warnings: warnings,
                                errors: errors,
                                messages: messages,
                                markdowns: markdowns,
                                previous_violations: {},
                                danger_id: danger_id,
                                template: "bitbucket_server")
    @api.post_comment(comment)
  end
end

#validates_as_api_source?Boolean

Returns:

  • (Boolean)


47
48
49
# File 'lib/danger/request_sources/bitbucket_server.rb', line 47

def validates_as_api_source?
  @api.credentials_given?
end

#validates_as_ci?Boolean

Returns:

  • (Boolean)


42
43
44
45
# File 'lib/danger/request_sources/bitbucket_server.rb', line 42

def validates_as_ci?
  # TODO: ???
  true
end